#ifndef NT2_INCLUDE_CONSTANTS_FOUR_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_FOUR_HPP_INCLUDED

#include <nt2/constant/include/constants/four.hpp>

#endif
